summaryrefslogtreecommitdiff
path: root/internal/cli/cli_test.go
diff options
context:
space:
mode:
authorPaul Buetow <paul@buetow.org>2026-03-02 10:54:03 +0200
committerPaul Buetow <paul@buetow.org>2026-03-02 10:54:03 +0200
commit88f6ca2fb24973b78afe76f82ea86171e40fccff (patch)
tree2ed7a46fd36fb37fc6a5a3b7037a41b75592e81e /internal/cli/cli_test.go
parent1bd6d282d2352870e68654afca3fa4a4ea7195ea (diff)
store/cli: deduplicate shred helper (task 400)
Diffstat (limited to 'internal/cli/cli_test.go')
-rw-r--r--internal/cli/cli_test.go8
1 files changed, 4 insertions, 4 deletions
diff --git a/internal/cli/cli_test.go b/internal/cli/cli_test.go
index 2ad52db..39c79aa 100644
--- a/internal/cli/cli_test.go
+++ b/internal/cli/cli_test.go
@@ -134,7 +134,7 @@ func TestPrintHelp(t *testing.T) {
}
}
// TestShredFileCli verifies that shredFile removes a temporary file.
// It uses a temp file so no live data is affected.
func TestShredFileCli(t *testing.T) {
dir := t.TempDir()
@@ -144,12 +144,12 @@ func TestShredFileCli(t *testing.T) {
}
ctx := t.Context()
- if err := shredFile(ctx, target); err != nil {
- t.Fatalf("shredFile: %v", err)
+ if err := store.ShredFile(ctx, target); err != nil {
+ t.Fatalf("ShredFile: %v", err)
}
if _, err := os.Stat(target); err == nil {
- t.Errorf("file %q still exists after shredFile", target)
+ t.Errorf("file %q still exists after ShredFile", target)
}
}
@@ -134,7 +134,7 @@ func TestPrintHelp(t *testing.T) {
}
}
-// TestShredFileCli verifies that shredFile removes a temporary file.
+// TestShredFileCli verifies that store.ShredFile removes a temporary file.
// It uses a temp file so no live data is affected.
func TestShredFileCli(t *testing.T) {